<?php
/**
 * @file
 * Enables modules and site configuration for a phpedu_profile site installation.
 */

use Drupal\contact\Entity\ContactForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements hook_form_FORM_ID_alter() for install_configure_form().
 *
 * Allows the profile to alter the site configuration form.
 */
function phpedu_profile_form_install_configure_form_alter(&$form, FormStateInterface $form_state) {
  // Add a value as example that one can choose an arbitrary site name.
  $form['site_information']['site_name']['#placeholder'] = t('University of Demo');

  // Add 'phpedu' fieldset and demo options.
  $form['phpedu'] = [
    '#type' => 'details',
    '#title' => t('Demo University Content'),
    '#description' => 'Optionally, populate the site with content to demonstrate phpEdu features. You may revert this content later.',
    '#weight' => -5,
    '#open' => TRUE,
  ];

  // Checkboxes to enable demo features.
  $form['phpedu']['extensions'] = [
    '#type' => 'checkboxes',
    '#options' => [
      'pe_migrate' => 'Configure demo content',
    ],
    '#default_value' => ['pe_migrate'],
  ];
  $form['phpedu']['extensions']['#default_value'] = array_keys($form['phpedu']['extensions']['#options']);

  $form['#submit'][] = 'phpedu_configure_demo_content';
}

/**
 * Enable extensions and configure demo content.
 */
function phpedu_configure_demo_content($form_id, &$form_state) {
  $extensions = array_filter($form_state->getValue('extensions'));
  if (isset($extensions)) {
    \Drupal::service('module_installer')->install($extensions, TRUE);
  //  @todo: run migrations.
  }
}
